@@ -65,8 +65,10 @@ slidy_presentation <- function(incremental = FALSE,
     args <- c(args, "--template", pandoc_path_arg(template))
 
   # html dependency for slidy
-  extra_dependencies <- append(extra_dependencies,
-                               list(html_dependency_slidy()))
+  extra_dependencies <- append(
+    extra_dependencies,
+    list(html_dependency_slidy(),
+         html_dependency_slidy_shiny()))
 
   # incremental
   if (incremental)
@@ -147,3 +149,13 @@ html_dependency_slidy <- function() {
     stylesheet = "styles/slidy.css"
   )
 }
+
+html_dependency_slidy_shiny <- function() {
+  htmlDependency(
+    name = "slidy_shiny",
+    version = "1",
+    src = pkg_file("rmd/slidy/"),
+    script = "slidy_shiny.js",
+    all_files = FALSE
+  )
+}
